SystemOrganization addCategory: #ConfigurationOfGemTools!

Object subclass: #ConfigurationOfGemTools
	instanceVariableNames: 'project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfGemTools'!

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
"
	<apiDocumentation>
! !

!ConfigurationOfGemTools class methodsFor: 'private' stamp: 'dkh 12/8/2009 10:56'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 1/14/2011 11:50'!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 A new baseline should be created if new packages have been added or package dependencies have changed."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	| currentVersion existingBaselineVersionString baselineVersionNumber |
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionNumber versionString
		for: self name asString
		from: existingBaselineVersionString
		description: ''! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
createNewDevelopmentVersion
	"Create a new development version using current version as model."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	| currentVersion developmentVersion |
	currentVersion := self project currentVersion.
	developmentVersion := currentVersion versionNumber copy incrementMinorVersionNumber.
	(Smalltalk at: #MetacelloToolBox)
		createDevelopment: developmentVersion versionString
		for: self name asString
		from: currentVersion versionString
		imports: currentVersion importedVersions
		description: ''! !

!ConfigurationOfGemTools class methodsFor: 'private' stamp: 'dkh 1/4/2010 11:03'!
ensureMetacello
        "Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
        version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [
                Smalltalk at: #Gofer ifAbsent: [
                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
                        self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
                Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                        gofer := goferClass new
                                url: 'http://seaside.gemstone.com/ss/metacello';
                                yourself.
                        [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                        gofer load ].
                "load latest version of Metacello, load a specific version if desired"
                (Smalltalk at: #ConfigurationOfMetacello) perform: #load ]

! !

!ConfigurationOfGemTools class methodsFor: 'metacello tool support' stamp: 'dkh 12/8/2009 10:56'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^self name ~= #GemToolsCommonConfiguration! !

!ConfigurationOfGemTools class methodsFor: 'loading' stamp: 'dkh 1/11/2010 11:53'!
load
	"self load"
	
	^self project latestVersion load! !

!ConfigurationOfGemTools class methodsFor: 'loading' stamp: 'dkh 1/11/2010 11:54'!
loadLatestVersion
	"self loadLatestVersion"
	
	self project updateProject.
	^self load! !

!ConfigurationOfGemTools class methodsFor: 'accessing' stamp: 'dkh 12/8/2009 10:55'!
project

	^self new project! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
releaseDevelopmentVersion: commitMessage
	"Release a version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	| version |
	version := self project version: #development.
	(Smalltalk at: #MetacelloToolBox)
		releaseVersion: version versionString for: self name asString;
		saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	<apiDocumentation>
	(Smalltalk at: #MetacelloToolBox)
		saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	<apiDocumentation>
	| version |
	version := self project version: #development.
	(Smalltalk at: #MetacelloToolBox)
		saveModifiedDevelopmentPackages: version versionString for: self name asString description: commitMessage;
		updateDevelopment: version versionString
			for: self name asString
			updateProjects: false
			description: commitMessage;
		saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:13'!
updateToLatestPackageVersions
	"Update the mcz file versions for current version of the configuration."

	"self updateToLatestPackageVersions"

	<apiDocumentation>
	((Smalltalk at: #MetacelloToolBox)
		updateDevelopment: #development
		for: self name asString
		updateProjects: false
		description: '') isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfGemTools class methodsFor: 'development support' stamp: 'DaleHenrichs 12/1/2010 19:17'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at.
	"
	
	"self validate"

	<apiDocumentation>
	^ (Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'DaleHenrichs 2/23/2010 16:13'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'Baseline GemTools client for Pharo/Squeak. Loads bleeding edge code.'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.2';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: { 'FFI'. 'OB-SUnitGUI'. } ];
			package: 'GemTools-Platform' with: [
				spec requires: { 'GemTools-Client'. } ]].
! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'DaleHenrichs 2/16/2010 20:45'!
baseline10beta3: spec 
	<version: '1.0-beta.3-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'Use ConfigurationOfOmniBrowser to load OB if not already installed'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.2';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' 'OB-Shout' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Shout' with: [
				spec
					className: 'ConfigurationOfShout';
					loads: 'Core';
					file: 'ConfigurationOfShout';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: #( 'FFI' 'OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #( 'GemTools-Client' ) ];
			yourself.

		spec group: 'default' with: #('OB-SUnitGUI' 'GemTools-Client' 'GemTools-Platform' ).

		spec for: #'OBNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'OB' ) ]].

		spec for: #'ShoutNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'Shout' ) ]]	].
	spec for: #pharo do: [
		spec
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'GemTools-Client' with: [
				spec includes: #( 'GemTools-ProfStef' ) ];
			package: 'GemTools-ProfStef' with: [
				spec requires: #('ProfStef' 'GemTools-Client') ];
			yourself.
		].! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'DaleHenrichs 2/26/2010 14:41'!
baseline10beta6: spec 
	<version: '1.0-beta.6-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'Use ConfigurationOfOmniBrowser to load OB if not already installed'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.2';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' 'OB-Shout' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Shout' with: [
				spec
					className: 'ConfigurationOfShout';
					loads: 'Core';
					file: 'ConfigurationOfShout';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: #( 'FFI' 'OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #( 'GemTools-Client' ) ];
			package: 'GemTools-Overrides';
			yourself.

		spec group: 'default' with: #('OB-SUnitGUI' 'GemTools-Client' 'GemTools-Platform' ).

		spec for: #'OBNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'OB' ) ]].

		spec for: #'ShoutNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'Shout' ) ]]	].
	spec for: #pharo do: [
		spec
			project: 'HelpSystem' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'GemTools-Client' with: [
				spec includes: #( 'GemTools-ProfStef' 'GemTools-Help') ];
			package: 'GemTools-ProfStef' ; "empty package at this point"
			package: 'GemTools-Help' with: [
				spec requires: #('HelpSystem' 'GemTools-Client') ];
			yourself.
		].! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'DaleHenrichs 10/5/2010 16:50'!
baseline10beta84: spec 
	<version: '1.0-beta.8.4-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'HelpBrowser on Squeak'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.2';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' 'OB-Shout' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Shout' with: [
				spec
					className: 'ConfigurationOfShout';
					loads: 'Core';
					file: 'ConfigurationOfShout';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'HelpSystem' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec 
					includes: #('GemTools-Help');
					requires: #( 'FFI' 'OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #( 'GemTools-Client' ) ];
			package: 'GemTools-Overrides';
			package: 'GemTools-Help' with: [
				spec requires: #('HelpSystem' 'GemTools-Client') ];
			yourself.

		spec group: 'default' with: #('OB-SUnitGUI' 'GemTools-Client' 'GemTools-Platform' ).

		spec for: #'OBNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'OB' ) ]].

		spec for: #'ShoutNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'Shout' ) ]]	].
! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'DaleHenrichs 7/14/2010 20:44'!
baseline10beta8: spec 
	<version: '1.0-beta.8-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'HelpBrowser on Squeak'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.2';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' 'OB-Shout' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Shout' with: [
				spec
					className: 'ConfigurationOfShout';
					loads: 'Core';
					file: 'ConfigurationOfShout';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'HelpSystem' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec 
					includes: #('GemTools-Help');
					requires: #( 'FFI' 'OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #( 'GemTools-Client' ) ];
			package: 'GemTools-Overrides';
			package: 'GemTools-Help' with: [
				spec requires: #('HelpSystem' 'GemTools-Client') ];
			yourself.

		spec group: 'default' with: #('OB-SUnitGUI' 'GemTools-Client' 'GemTools-Platform' ).

		spec for: #'OBNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'OB' ) ]].

		spec for: #'ShoutNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'Shout' ) ]]	].
	spec for: #pharo do: [
		spec
			package: 'GemTools-Client' with: [
				spec includes: #( 'GemTools-ProfStef' ) ];
			package: 'GemTools-ProfStef' ; "empty package at this point"
			yourself.
		].! !

!ConfigurationOfGemTools methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 12/1/2010 19:16'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.0-beta.8.4'. 
! !

!ConfigurationOfGemTools methodsFor: 'doits' stamp: 'DaleHenrichs 10/4/2010 16:17'!
preloadDoitForPharo11

	Preferences allowUnderscoreAssignmentSetting: true.
	Deprecation raiseWarning: false.! !

!ConfigurationOfGemTools methodsFor: 'accessing' stamp: 'DaleHenrichs 10/4/2010 16:37'!
project

	| versionString projectAttributes |
	^ project ifNil: [
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		Smalltalk at: #SystemVersion ifPresent: [:cl |
			versionString := cl current version.
			(versionString beginsWith: 'Pharo') 
				ifTrue: [
					(versionString beginsWith: 'Pharo0.1')
						ifFalse: [ 
							projectAttributes := projectAttributes, #(#'pharo1.0Beta').
							((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
								ifTrue: [ projectAttributes := projectAttributes, #(#'GemToolsForPharo1.0') ]
								ifFalse: [ projectAttributes := projectAttributes, #(#'GemToolsForPharo1.1') ] ]]].
		Smalltalk at: #OBNode ifAbsent: [ projectAttributes := projectAttributes, #(#'OBNotPresent') ].
		Smalltalk at: #SHParserST80 ifAbsent: [ projectAttributes := projectAttributes, #(#'ShoutNotPresent') ].
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear]! !

!ConfigurationOfGemTools methodsFor: 'symbolic versions' stamp: 'DaleHenrichs 12/1/2010 19:15'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '1.0-beta.8.3'. 
! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 10/15/2009 14:43'!
version10beta0: spec
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: 'GemTools client for Pharo/Squeak. Initial beta.'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client.experimental-dkh.495';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.2'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.4'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 11/3/2009 14:03'!
version10beta1: spec
	<version: '1.0-beta.1' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: '- Convert to using ConfigurationOfGemTools
- nicer info dialog when Undefined symbols and unsent messages are clean
- support for 3.0 GciErrSType
- change restore from backup done message ... do not prompt to start Seaside gems if Seaside is not installed
- replace dialogs that are calling "ifNotEmpty:" with: "isEmptyOrNil" (from Gerhard)
- autoAbort _before_ commands is now optional (off by default)
'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-dkh.504';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.3'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 12/2/2009 14:15'!
version10beta2: spec
	<version: '1.0-beta.2' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: '- fix update client logic to use #lastMetacelloVersionLoad
- change annotation pane and make more room for useful info
- inspect undefined and inspect sent but not implemented menu items available only when available
- clean up preferences problems when not present
- Admin>>Seaside submen available only when Seaside2.8 installed
- improve session window label (include the session name) when working with multiple stones
'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-dkh.509';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.3'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 1/25/2010 09:46'!
version10beta3: spec
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- improve ''Show Object log'' output format
- add ''List backup files'' command
- add some missing icon definitions for Squeak
- load OB/Shout if not present
- ProfStef tutorials (Pharo only)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/25/2010 09:46'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.513';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.9'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'JamesFoster 2/2/2010 14:16'!
version10beta4: spec
	<version: '1.0-beta.4' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- Rename GCI library for Squeak 3.11.3-2135
'.
		spec author: 'JamesFoster'.
		spec timestamp: '2/2/2010 14:14'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-JamesFoster.514';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.9'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 2/8/2010 15:33'!
version10beta5: spec
	<version: '1.0-beta.5' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix bug in the new GCI library code ... linux-gnu is also a valid os name
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '2/8/2010 15:33'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.515';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.9'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 5/26/2010 16:21'!
version10beta6: spec
	<version: '1.0-beta.6' imports: #('1.0-beta.6-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fixed highlighting for class definition/creation template
- enabled syntax highlighting in workspaces
- double click includes leading $_. In package GemTools-Overrides that is not loaded by default, because it stomps on a method in Character.
- GsOBColumnPanel>>currentNode sends #currentNode to server-side, fixing a couple of ancient bugs
- reset GLASS version after doing a Server update
- exclude #baseline versions from update glass client version list
- add proportional splitters to inspectors (resize panes vertically)
- Use Help System instead of ProfStef
- fix Issue 54: http://code.google.com/p/glassdb/issues/detail?id=54 "Typos and unclear instructions in GemTools ProfStef tutorial"
- fix Issue 104: http://code.google.com/p/glassdb/issues/detail?id=104 "Title for Update GLASS version list window incorrect"
- fix Issue 115: http://code.google.com/p/glassdb/issues/detail?id=115 "GettingStartedWithGLASS doesn''t mention when to start the stone or the gems for a native installation"
- workaround for Issue 105: http://code.google.com/p/glassdb/issues/detail?id=105 "Gofer Project loader in or out of GLASS config"
- add ''Admin>>Doit...>>Version Report'' menu item (included in bug report template) that shows versions of all installed configs
- add toggle ''Admin>>Commit on Almost Out of Memory'' command
- upgrade path from 0.231,  0.232.2 and 1.0-beta.0 through 1.0-beta.7 to 1.0-beta.8
- help browser info corresponds with http://code.google.com/p/glassdb/wiki/GettingStartedWithGLASS#Backup_repository page in glassdb
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/26/2010 16:10'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.538';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec project: 'HelpSystem' with: '1.0'.
		spec 
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.23';
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 7/13/2010 15:32'!
version10beta7: spec
	<version: '1.0-beta.7' imports: #('1.0-beta.6-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- add support for start/stop/restart Seaside30 gems
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/9/2010 13:17'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.540';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec project: 'HelpSystem' with: '1.0'.
		spec 
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.23';
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 7/29/2010 15:35'!
version10beta81: spec
	<version: '1.0-beta.8.1' imports: #('1.0-beta.8-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- upgrade GLASS support for GemStone 3.0
- fix a problem in restartSeaside gems after restore'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/29/2010 13:10'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'HelpSystem' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.542';
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.24';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec 
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 8/23/2010 14:46'!
version10beta82: spec
	<version: '1.0-beta.8.2' imports: #('1.0-beta.8-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- improve debugger window title error messages for UserDefinedErrors and Halts. Need GLASS 1.0-beta.8.3 or later to see the improved results (see Issue 32: http://code.google.com/p/glassdb/issues/detail?id=32).'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '8/17/2010 17:30'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'HelpSystem' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.543';
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.24';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec 
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 10/4/2010 16:50'!
version10beta83: spec
	<version: '1.0-beta.8.3' imports: #('1.0-beta.8-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- pick up Pharo 1.1 changes from Norbert'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '10/4/2010 15:56'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'HelpSystem' with: '1.0'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.24';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec 
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'GemToolsForPharo1.0' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.543'].
	spec for: #'GemToolsForPharo1.1' do: [
		spec project: 'OB' with: '1.1.4'.
		spec 
			preLoadDoIt: #preloadDoitForPharo11;
			package: 'GemTools-Client' with: 'GemTools-Client-NorbertHartl.544'].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 12/16/2010 12:43'!
version10beta84: spec
	<version: '1.0-beta.8.4' imports: #('1.0-beta.8.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- consolidate changes, so that we''re back to one GemTools-Client that works in both Pharo1.0 and Pharo1.1
- no longer need GemTools-ProfStef
- tweaks for Pharo 1.1.1 (pick up Johan''s changes, but use UIManager instead of PopUpMenu)
- significant performance improvement when using SHOUT ... reduce round trips drastically!!
- fix Issue 171: http://code.google.com/p/glassdb/issues/detail?id=171 "need to be able to set ''Popup on debug'' without having to login"
- fix Issue 167: http://code.google.com/p/glassdb/issues/detail?id=167 "Admin>>Repository>>restore w/tranlogs should be removed"
- fix Issue 143: http://code.google.com/p/glassdb/issues/detail?id=143 "incorrect download path in help browser"
- port Help Browser topics to version 1.1 of HelpSystem
- 3.0 gci compatability
- fixed Issue 204: http://code.google.com/p/glassdb/issues/detail?id=204 "remove _ assignments from GemTools code"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/16/2010 12:40'.
].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'HelpSystem' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.559';
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.26';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].

	spec for: #'GemToolsForPharo1.0' do: [
		spec project: 'OB' with: '1.1'.].

	spec for: #'GemToolsForPharo1.1' do: [
		spec preLoadDoIt: #'preloadDoitForPharo11'.
		spec project: 'OB' with: '1.1.4'.].

	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-DaleHenrichs.7'.].
! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'DaleHenrichs 7/15/2010 10:27'!
version10beta8: spec
	<version: '1.0-beta.8' imports: #('1.0-beta.8-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- update instructions for building your own GemTools image (add GemStone/S 2.4 instructions)
- use HelpBrowser for Squeak
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/14/2010 20:23'.
].
	spec for: #squeakCommon do: [
		spec 
			project: 'Shout' with: '1.0';
			project: 'HelpSystem' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-DaleHenrichs.540';
			package: 'GemTools-Help' with: 'GemTools-Help-DaleHenrichs.24';
			package: 'GemTools-Overrides' with: 'GemTools-Overrides-DaleHenrichs.1';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #pharo do: [
		spec 
			package: 'GemTools-ProfStef' with: 'GemTools-ProfStef-DaleHenrichs.13'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !
